pub type CompactLattice<A> = VectorFst<CompactLatticeArc<A>>;Expand description
A lattice with one arc per word, for a decoding graph over A.
Aliased Type
pub struct CompactLattice<A> { /* private fields */ }pub type CompactLattice<A> = VectorFst<CompactLatticeArc<A>>;A lattice with one arc per word, for a decoding graph over A.
pub struct CompactLattice<A> { /* private fields */ }