Decoded

Struct Decoded 

pub struct Decoded<A: Arc> {
    pub labels: Vec<A::Label>,
    pub weight: A::Weight,
}
The best path through the graph, given the acoustic scores.

Fields

labels: Vec<A::Label>

The output labels along the path, epsilons removed.

weight: A::Weight

The path’s weight: the graph’s costs, the acoustic scores and the final weight, all multiplied together.